@@ -1,20 +1,17 @@
 package App::RecordStream::Aggregator::Average;
 
-our $VERSION = "3.4";
-
 use strict;
 use lib;
 
 use App::RecordStream::Aggregator::Ord2Univariate;
 use App::RecordStream::Aggregator;
+use App::RecordStream::DomainLanguage::Registry;
 
 use base 'App::RecordStream::Aggregator::Ord2Univariate';
 
-sub new
-{
-   my ($class, @args) = @_;
-   return $class->SUPER::new(@args);
-}
+#sub new -- passed through
+
+#sub new_from_valuation -- passed through
 
 sub squish
 {
@@ -40,4 +37,7 @@ sub short_usage
 App::RecordStream::Aggregator::register_aggregator('average', __PACKAGE__);
 App::RecordStream::Aggregator::register_aggregator('avg', __PACKAGE__);
 
+App::RecordStream::DomainLanguage::Registry::register_vfn(__PACKAGE__, 'new_from_valuation', 'average', 'VALUATION');
+App::RecordStream::DomainLanguage::Registry::register_vfn(__PACKAGE__, 'new_from_valuation', 'avg', 'VALUATION');
+
 1;
