@@ -1,20 +1,17 @@
 package App::RecordStream::Aggregator::Covariance;
 
-our $VERSION = "3.4";
-
 use strict;
 use lib;
 
 use App::RecordStream::Aggregator::Ord2Bivariate;
 use App::RecordStream::Aggregator;
+use App::RecordStream::DomainLanguage::Registry;
 
 use base 'App::RecordStream::Aggregator::Ord2Bivariate';
 
-sub new
-{
-   my ($class, @args) = @_;
-   return $class->SUPER::new(@args);
-}
+#sub new -- passed through
+
+#sub new_from_valuation -- passed through
 
 sub squish
 {
@@ -40,8 +37,13 @@ sub short_usage
 }
 
 App::RecordStream::Aggregator::register_aggregator('cov', __PACKAGE__);
+App::RecordStream::Aggregator::register_aggregator('covar', __PACKAGE__);
 App::RecordStream::Aggregator::register_aggregator('covariance', __PACKAGE__);
 
+App::RecordStream::DomainLanguage::Registry::register_vfn(__PACKAGE__, 'new_from_valuation', 'cov', 'VALUATION', 'VALUATION');
+App::RecordStream::DomainLanguage::Registry::register_vfn(__PACKAGE__, 'new_from_valuation', 'covar', 'VALUATION', 'VALUATION');
+App::RecordStream::DomainLanguage::Registry::register_vfn(__PACKAGE__, 'new_from_valuation', 'covariance', 'VALUATION', 'VALUATION');
+
 1;
 
 __DATA__
