@@ -1,21 +1,30 @@
 package App::RecordStream::Aggregator::DistinctCount;
 
-our $VERSION = "3.4";
-
 use strict;
 use lib;
 
 use App::RecordStream::Aggregator;
+use App::RecordStream::DomainLanguage::Registry;
+use App::RecordStream::DomainLanguage::Valuation::KeySpec;
+
 use base qw(App::RecordStream::Aggregator::Aggregation);
 
 sub new
 {
    my $class = shift;
-   my ($field) = @_;
+   my $field = shift;
+
+   return new_from_valuation($class, App::RecordStream::DomainLanguage::Valuation::KeySpec->new($field));
+}
+
+sub new_from_valuation
+{
+   my $class = shift;
+   my ($valuation) = @_;
 
    my $this =
    {
-      'field' => $field,
+      'valuation' => $valuation,
    };
    bless $this, $class;
 
@@ -59,7 +68,8 @@ sub combine
 {
    my ($this, $cookie, $record) = @_;
 
-   my $value = ${$record->guess_key_from_spec($this->{'field'})};
+   my $value = $this->{'valuation'}->evaluate_record($record);
+
    $cookie->{$value} = 1;
 
    return $cookie;
@@ -70,4 +80,9 @@ App::RecordStream::Aggregator::register_aggregator('dct', __PACKAGE__);
 App::RecordStream::Aggregator::register_aggregator('distinctcount', __PACKAGE__);
 App::RecordStream::Aggregator::register_aggregator('distinctct', __PACKAGE__);
 
+App::RecordStream::DomainLanguage::Registry::register_vfn(__PACKAGE__, 'new_from_valuation', 'dcount', 'VALUATION');
+App::RecordStream::DomainLanguage::Registry::register_vfn(__PACKAGE__, 'new_from_valuation', 'dct', 'VALUATION');
+App::RecordStream::DomainLanguage::Registry::register_vfn(__PACKAGE__, 'new_from_valuation', 'distinctcount', 'VALUATION');
+App::RecordStream::DomainLanguage::Registry::register_vfn(__PACKAGE__, 'new_from_valuation', 'distinctct', 'VALUATION');
+
 1;
