@@ -1,20 +1,16 @@
 package App::RecordStream::Aggregator::First;
 
-our $VERSION = "3.4";
-
 use strict;
 use lib;
 
 use App::RecordStream::Aggregator::InjectInto::Field;
+use App::RecordStream::DomainLanguage::Registry;
+
 use base qw(App::RecordStream::Aggregator::InjectInto::Field);
 
-sub new
-{
-   my $class = shift;
-   my @args  = @_;
+#sub new -- passed through
 
-   return $class->SUPER::new(@args);
-}
+#sub new_from_valuation -- passed through
 
 sub combine_field
 {
@@ -39,4 +35,6 @@ sub long_usage
 
 App::RecordStream::Aggregator::register_aggregator('first', __PACKAGE__);
 
+App::RecordStream::DomainLanguage::Registry::register_vfn(__PACKAGE__, 'new_from_valuation', 'first', 'VALUATION');
+
 1;
