@@ -1,21 +1,29 @@
 package App::RecordStream::Aggregator::MapReduce::FieldSet;
 
-our $VERSION = "3.4";
-
 use strict;
 use lib;
 
 use App::RecordStream::Aggregator::MapReduce;
+use App::RecordStream::DomainLanguage::Valuation::KeySpec;
 
 use base 'App::RecordStream::Aggregator::MapReduce';
 
 sub new
 {
    my $class = shift;
+   my @fields = @_;
+
+   return new_from_valuation($class, map { App::RecordStream::DomainLanguage::Valuation::KeySpec->new($_) } @fields);
+}
+
+sub new_from_valuation
+{
+   my $class = shift;
+   my @valuations = @_;
 
    my $this =
    {
-      'fields' => \@_,
+      'valuations' => \@valuations,
    };
    bless $this, $class;
 
@@ -26,7 +34,7 @@ sub map
 {
    my ($this, $record) = @_;
 
-   return $this->map_fields(map { ${$record->guess_key_from_spec($_)} } @{$this->{'fields'}});
+   return $this->map_fields(map { $_->evaluate_record($record) } @{$this->{'valuations'}});
 }
 
 sub map_fields
