@@ -1,12 +1,11 @@
 package App::RecordStream::Aggregator::Records;
 
-our $VERSION = "3.4";
-
 use strict;
 use lib;
 
 use App::RecordStream::Aggregator::MapReduce;
 use App::RecordStream::Aggregator;
+use App::RecordStream::DomainLanguage::Registry;
 
 use base 'App::RecordStream::Aggregator::MapReduce';
 
@@ -62,4 +61,7 @@ sub returns_record
 App::RecordStream::Aggregator::register_aggregator('records', __PACKAGE__);
 App::RecordStream::Aggregator::register_aggregator('recs', __PACKAGE__);
 
+App::RecordStream::DomainLanguage::Registry::register_ctor(__PACKAGE__, 'records');
+App::RecordStream::DomainLanguage::Registry::register_ctor(__PACKAGE__, 'recs');
+
 1;
