@@ -1,9 +1,7 @@
 package App::RecordStream::Aggregator::Minimum;
 
-our $VERSION = "3.4";
-
 use strict;
-use warnings;
+use lib;
 
 use App::RecordStream::Aggregator::InjectInto::Field;
 use App::RecordStream::DomainLanguage::Registry;
@@ -16,31 +14,30 @@ use base qw(App::RecordStream::Aggregator::InjectInto::Field);
 
 sub combine_field
 {
-  my $this   = shift;
-  my $cookie = shift;
-  my $value  = shift;
+   my $this   = shift;
+   my $cookie = shift;
+   my $value  = shift;
 
-  return $value unless ( defined $cookie );
+   return $value unless ( defined $cookie );
 
-  if ( $cookie > $value )
-  {
-    return $value;
-  }
+   if ( $cookie > $value )
+   {
+      return $value;
+   }
 
-  return $cookie;
+   return $cookie;
 }
 
 sub short_usage
 {
-  return "minimum value for a field";
+   return "minimum value for a field";
 }
 
 sub long_usage
 {
-  return <<EOF;
-Usage: min,<field>
-   Minimum value of specified field.
-EOF
+   print "Usage: min,<field>\n";
+   print "   Minimum value of specified field.\n";
+   exit 1;
 }
 
 App::RecordStream::Aggregator::register_aggregator('minimum', __PACKAGE__);
