@@ -1,9 +1,7 @@
 package App::RecordStream::Aggregator::Variance;
 
-our $VERSION = "3.4";
-
 use strict;
-use warnings;
+use lib;
 
 use App::RecordStream::Aggregator::Ord2Univariate;
 use App::RecordStream::Aggregator;
@@ -17,27 +15,25 @@ use base 'App::RecordStream::Aggregator::Ord2Univariate';
 
 sub squish
 {
-  my ($this, $cookie) = @_;
+   my ($this, $cookie) = @_;
 
-  my ($sum1, $sumx, $sumx2) = @$cookie;
+   my ($sum1, $sumx, $sumx2) = @$cookie;
 
-  return ($sumx2 / $sum1) - ($sumx / $sum1) ** 2;
+   return ($sumx2 / $sum1) - ($sumx / $sum1) ** 2;
 }
 
 sub long_usage
 {
-  return <<EOF;
-Usage: var,<field1>
-   Variance of specified fields.
-
-   This is computed as Var(X) = E[(X - E[X])^2].  Variance is an indication of
-   deviation from average value.
-EOF
+   while(my $line = <DATA>)
+   {
+      print $line;
+   }
+   exit 1;
 }
 
 sub short_usage
 {
-  return "find variance of provided field";
+   return "find variance of provided field";
 }
 
 App::RecordStream::Aggregator::register_aggregator('var', __PACKAGE__);
@@ -47,3 +43,10 @@ App::RecordStream::DomainLanguage::Registry::register_vfn(__PACKAGE__, 'new_from
 App::RecordStream::DomainLanguage::Registry::register_vfn(__PACKAGE__, 'new_from_valuation', 'variance', 'VALUATION');
 
 1;
+
+__DATA__
+Usage: var,<field1>
+   Variance of specified fields.
+
+This is computed as Var(X) = E[(X - E[X])^2].  Variance is an indication of
+deviation from average value.
