@@ -61,13 +61,14 @@ field.
 
 Calls $this->set("XXX", $value);
 
-=item @old_values = $this->remove(@keys);
+=item $old_value = $this->remove($key);
 
-Remove fields from the record, returns the old values (or undef for each missing).
+Remove a field from the record, returns the old value, or undef if there was no
+such field.
 
-=item $this->prune_to(@keys);
+=item $this->prune(@keys);
 
-Removes fields whose names are not among those provided.
+Removes any fields whose names are not among those provided.
 
 =item $this->rename($old_key, $new_key);
 
@@ -150,8 +151,6 @@ records.
 
 =cut
 
-our $VERSION = "3.4";
-
 use strict;
 use warnings;
 
@@ -326,18 +325,15 @@ sub set
 
 sub remove
 {
-   my ($this, @fields) = @_;
+   my ($this, $field) = @_;
 
-   my @old;
-   for my $field (@fields)
-   {
-      push @old, delete $this->{$field};
-   }
+   my $old = $this->{$field};
+   delete $this->{$field};
 
-   return @old;
+   return $old;
 }
 
-sub prune_to
+sub prune
 {
    my ($this, @ok) = @_;
 
@@ -371,11 +367,6 @@ sub as_hashref
    return {%$this};
 }
 
-sub TO_JSON {
-  my ($this) = @_;
-  return $this->as_hashref();
-}
-
 my $guessed_keys = {};
 
 sub _search_string_to_key {
